| distance_results | R Documentation |
A data frame with nearest distances for each reference cell
data("distance_results")
A data frame with 18 observations on the following 5 variables.
Newbarcodea character vector
Epithelial_cells_Aa numeric vector
Epithelial_cells_Ba numeric vector
Epithelial_cells_Ca numeric vector
Epithelial_cells_Da numeric vector
A data frame with nearest distances for each reference cell.
This study.
Wang, Z., Yang, L., Yang, S., Li, G., Xu, M., Kong, B., Shao, C., & Liu, Z. (2025). Isoform switch of CD47 provokes macrophage-mediated pyroptosis in ovarian cancer. bioRxiv, 2025.2004.2017.649282. https://doi.org/10.1101/2025.04.17.649282
data(distance_results)
## maybe str(distance_results) ; plot(distance_results) ...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.