powered by
A data frame with nearest distances for each reference cell
data("distance_results")
A data frame with 18 observations on the following 5 variables.
Newbarcode
a character vector
Epithelial_cells_A
a numeric vector
Epithelial_cells_B
Epithelial_cells_C
Epithelial_cells_D
A data frame with nearest distances for each reference cell.
Wang, Z., Yang, L., Yang, S., Li, G., Xu, M., Kong, B., Shao, C., & Liu, Z. (2025). Isoform switch of CD47 provokes macrophage-mediated pyroptosis in ovarian cancer. bioRxiv, 2025.2004.2017.649282. https://doi.org/10.1101/2025.04.17.649282
data(distance_results) ## maybe str(distance_results) ; plot(distance_results) ...
Run the code above in your browser using DataLab